==> aprs4r-0.9.9.1.tar.gz: aprs4r-0.9.9.1/src/aprs4r/PluginConfiguration.rb <==
#
#  APRS4R - a ruby based aprs gateway/digipeater
#  Copyright (C) 2006 by Michael Conrad <do5mc@friggleware.de>
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation; either version 2 of the License, or
#  (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program; if not, write to the Free Software
#  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
#

require 'aprs4r/APRSCall'

module APRS4R

  class PluginConfiguration

    attr_reader :name, :type, :enable
    attr_writer :name, :type, :enable


    def to_yaml_properties
      return %w{ @name @type @enable}
    end


    def attributes

      attributes = [ 
                    ConfigurationAttribute.new( "name",   "text",    true,  10, nil,   "Name"), 
                    ConfigurationAttribute.new( "type",   "text",    false, 10, nil,   "Typ"), 
                    ConfigurationAttribute.new( "enable", "boolean", true,  10, false, "aktiviert"), 
                   ]

      return attributes
    end


    def PluginConfiguration.subtypes
      return [ "BeaconPlugin", "ProportionalBeaconPlugin", "GatewayPlugin", "DigipeaterPlugin", "MessagePlugin", "WMRWeatherPlugin", "ISServerPlugin", "XMLDataPlugin"]
    end

  end

end

==> aprs4r-0.9.9.4.tar.gz: aprs4r-0.9.9.4/src/aprs4r/PluginConfiguration.rb <==
#
#  APRS4R - a ruby based aprs gateway/digipeater
#  Copyright (C) 2006 by Michael Conrad <do5mc@friggleware.de>
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation; either version 2 of the License, or
#  (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program; if not, write to the Free Software
#  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
#

require 'aprs4r/APRSCall'

module APRS4R

  class PluginConfiguration

    attr_reader :name, :type, :enable
    attr_writer :name, :type, :enable


    def to_yaml_properties
      return %w{ @name @type @enable}
    end


    def attributes

      online_url = "http://afu.friggleware.de/cgi-bin/trac.cgi/wiki/APRS4RConfigurationPlugins#{@type}German"

      attributes = [ 
                    ConfigurationAttribute.new( "name",   "text",    true,  10, nil,   "Name"), 
                    ConfigurationAttribute.new( "type",   "text",    false, 10, nil,   "Typ", online_url), 
                    ConfigurationAttribute.new( "enable", "boolean", true,  10, false, "aktiviert"), 
                   ]

      return attributes
    end


    def PluginConfiguration.subtypes
      return [ "BeaconPlugin", "WeatherBeaconPlugin", "GatewayPlugin", "DigipeaterPlugin", "MessagePlugin", "WMRWeatherPlugin", "ISServerPlugin", "XMLDataPlugin"]
    end

  end

end
